/*
 *	 Title:	Library fr RTC "DS 12C887" oder kompatible
 *	Author: Andreas Hummel (a.hummel@neblis.de)
 *
 *	Hardware:
 *	Getestet auf ATmega16 und mit RTC "ODIN OEC12C887"
 *
 *	Beschreibung:
 *	Einfache Lib, mit der 12C887 RTC's angesprochen werden knnen.
 *	Die definitionen welcher PIN der RTC an welchem AVR-Pin hngt, werden in der
 *  rtc.h-Datei festgelegt.
 *
 *	Siehe auch beiliegendem Anschluschema "connect.gif".
 */
 
#ifndef RTC_H
#define RTC_H

// Data Read&Set-Pins
#define RTC_ADDR	PORTA
#define RTC_DATA	PINA
#define RTC_DDR_A	DDRA

// Control-Pins
#define RTC_CTRL	PORTC
#define RTC_DDR_C	DDRC
#define RTC_DS	PC6
#define RTC_RW	PC5
#define RTC_AS	PC4
#define RTC_CS	PC3

// Defines fr Datenpositionen
#define RTC_A_SEC			0x00
#define RTC_A_MIN			0x02
#define RTC_A_HOUR			0x04
#define RTC_A_DAY_OF_WEEK	0x06
#define RTC_A_DAY			0x07
#define RTC_A_MONTH			0x08
#define RTC_A_YEAR			0x09
#define RTC_A_CENTURY		0x50

#define RTC_A_SEC_ALARM		0x01
#define RTC_A_MIN_ALARM		0x03
#define RTC_A_HOUR_ALARM	0x05

#define RTC_A_REG_A			0x0A
#define RTC_A_REG_B			0x0B
#define RTC_A_REG_C			0x0C
#define RTC_A_REG_D			0x0D

#define RTC_BIT_B_SET		7
#define RTC_BIT_B_PIE		6
#define RTC_BIT_B_AIE		5
#define RTC_BIT_B_UIE		4
#define RTC_BIT_B_SQWE		3
#define RTC_BIT_B_DMODE		2
#define RTC_BIT_B_2412		1
#define RTC_BIT_B_DSE		0

// Initialisiert die PORTs an denen die RTC hngt.
void 			rtc_init( void );

// Schreibt ein Byte auf die RTC an die angegebene Adresse.
void 			rtc_write_byte( unsigned char address, unsigned char data );

// Liest ein Byte aus der RTC an der angegebenen Adresse.
unsigned char 	rtc_read_byte( unsigned char address );

// Gibt eine deutsch formatierte Uhrzeit zurck. Buffer muss mindestens 9 Zeichen lang sein.
char* 			rtc_get_time( char* buffer );

// Gibt eine deutsch formatiertes Datum zurck. Buffer muss mindestens 11 Zeichen lang sein.
char* 			rtc_get_date( char* buffer );

// Gibt den deutschen Wochentag zurck. Buffer muss mindestens 3 Zeichen lang sein.
char*			rtc_get_day_of_week( char* buffer );

// Gibt "TRUE" zurck, falls die Lithiumbatterie in dem RTC in Ordnung ist, sonst "FALSE"
unsigned char	rtc_check_battery( void );

#endif // RTC_H